import json
import gspread
from oauth2client.service_account import ServiceAccountCredentials
import os

# ================================
# ✅ Google Sheets API Setup
# ================================
SHEET_NAME = "JsonSubmissions"
CREDENTIALS_FILE = "sheetsapi-449405-0037afe11f41.json"
JSON_FILE = "submissions.json"

# Define required Google API scopes
scope = ["https://spreadsheets.google.com/feeds", "https://www.googleapis.com/auth/drive"]

# Load credentials and authorize access
creds = ServiceAccountCredentials.from_json_keyfile_name(CREDENTIALS_FILE, scope)
client = gspread.authorize(creds)

# Open the correct Google Sheet
sheet = client.open(SHEET_NAME).sheet1
print(f"📢 Connected to Google Sheet: {sheet.title}")

# ================================
# ✅ Function: parse_submission(data)
# ================================
def parse_submission(data):
    print("🔍 Parsing submission:", data)

    if not isinstance(data, dict):
        print("❌ Error: Expected dictionary but got:", type(data))
        return None, None, "N/A", {}, {}, ""

    lead_id = data.get("leadId", "N/A")
    client_id = data.get("clientId", "N/A")
    timestamp = data.get("timestamp", "N/A")
    form_data = data.get("submissions", {})

    if isinstance(form_data, str):
        try:
            form_data = json.loads(form_data)
        except json.JSONDecodeError:
            print("❌ Error: 'submissions' is a string but not valid JSON!")
            return lead_id, timestamp, client_id, {}, {}, ""

    utm_params = data.get("utmParameters", {})
    sent_to_airtable = data.get("sentToAirtable", "")  # default = empty string

    print("✅ Extracted Data:", lead_id, client_id, timestamp, form_data, utm_params, sent_to_airtable)
    return lead_id, timestamp, client_id, form_data, utm_params, sent_to_airtable

# ================================
# ✅ Function: update_google_sheet()
# ================================
def update_google_sheet():
    if not os.path.exists(JSON_FILE):
        print("❌ JSON file not found.")
        return

    try:
        with open(JSON_FILE, "r") as f:
            raw_data = f.read().strip()
            print("📢 Raw JSON data (first 500 chars):", raw_data[:500])
            if raw_data.startswith('"') and raw_data.endswith('"'):
                print("🚨 JSON is stored as a STRING instead of a LIST. Fixing...")
                raw_data = json.loads(raw_data)
            data = json.loads(raw_data)
            if not isinstance(data, list):
                print("❌ Error: Expected a list of dictionaries but got:", type(data))
                return
    except json.JSONDecodeError as e:
        print(f"❌ JSON Decode Error: {e}")
        return

    if not data:
        print("⚠️ No data found in JSON.")
        return

    try:
        existing_ids = set(sheet.col_values(2)[1:])  # Column B = leadId
        print(f"📢 Existing IDs in Google Sheet: {len(existing_ids)} entries found.")
    except Exception as e:
        print(f"❌ Error fetching existing sheet data: {e}")
        existing_ids = set()

    # Headers including sentToAirtable
    expected_headers = [
        "clientId", "leadId", "timestamp", "equipment", "zipCode", "homeValue", "bill",
        "firstName", "lastName", "address", "homeowner",
        "email", "phone",
        "utm_source", "utm_medium", "utm_campaign", "utm_content", "adgroup",
        "device", "gclid", "wbraid", "cacheBuster", "lpurl",
        "sentToAirtable"
    ]

    # Normalize existing headers to avoid duplicates
    sheet_headers = [h.strip().lower() for h in sheet.row_values(1)]
    expected_normalized = [h.strip().lower() for h in expected_headers]

    if sheet_headers != expected_normalized:
        print("⚠️ Headers missing or incorrect. Replacing headers...")
        sheet.delete_rows(1)
        sheet.insert_row(expected_headers, index=1)

    new_rows = []

    for entry in data:
        lead_id, timestamp, client_id, submission_data, utm_data, sent_to_airtable = parse_submission(entry)

        if lead_id is None or lead_id in existing_ids:
            print(f"🚨 Skipping duplicate entry: {lead_id}")
            continue

        if not isinstance(submission_data, dict):
            print(f"❌ Error: Expected dictionary for submissions, but got {type(submission_data)}")
            continue

        row_data = [client_id, lead_id, timestamp] + \
                   [submission_data.get(h, "N/A") for h in expected_headers[3:13]] + \
                   [utm_data.get(h, "N/A") for h in expected_headers[13:-1]] + \
                   [sent_to_airtable]

        new_rows.append(row_data)
        existing_ids.add(lead_id)

    if new_rows:
        try:
            print(f"🚀 Writing {len(new_rows)} new rows to Google Sheets...")
            sheet.append_rows(new_rows, value_input_option="RAW")
            print(f"✅ Successfully added {len(new_rows)} new rows to Google Sheets.")
        except Exception as e:
            print(f"❌ Google Sheets Append Error: {e}")
    else:
        print("✅ No new data to add.")

# Run the update
update_google_sheet()