import json
import gspread
from oauth2client.service_account import ServiceAccountCredentials
import os

# ================================
# ✅ Google Sheets API Setup
# ================================
SHEET_NAME = "JsonSubmissions"
CREDENTIALS_FILE = "sheetsapi-449405-0037afe11f41.json"
JSON_FILE = "fullSubmissions.json"

# Google API scopes
scope = ["https://spreadsheets.google.com/feeds", "https://www.googleapis.com/auth/drive"]

# Auth and get Sheet2
creds = ServiceAccountCredentials.from_json_keyfile_name(CREDENTIALS_FILE, scope)
client = gspread.authorize(creds)
sheet = client.open(SHEET_NAME).get_worksheet(1)  # Sheet2 is index 1
print(f"📢 Connected to Sheet2: {sheet.title}")

# ================================
# ✅ Parse each entry
# ================================
def parse_submission(data):
    lead_id = data.get("leadId", "N/A")
    client_id = data.get("clientId", "N/A")
    timestamp = data.get("timestamp", "N/A")
    form_data = data.get("submissions", {})
    return lead_id, client_id, timestamp, form_data

# ================================
# ✅ Update Sheet2
# ================================
def update_google_sheet():
    if not os.path.exists(JSON_FILE):
        print("❌ JSON file not found.")
        return

    with open(JSON_FILE, "r") as f:
        raw = f.read().strip()
        if raw.startswith('"') and raw.endswith('"'):
            raw = json.loads(raw)
        data = json.loads(raw)

    if not isinstance(data, list):
        print("❌ Expected list of dicts.")
        return
    if not data:
        print("⚠️ fullSubmissions.json is empty.")
        return

    try:
        existing_ids = set(sheet.col_values(1)[1:])  # Column A = leadId
    except Exception as e:
        print(f"❌ Error reading sheet: {e}")
        existing_ids = set()

    # ✅ Only include keys available in fullSubmissions.json
    expected_headers = ["leadId", "clientId", "timestamp", "email", "phone"]

    # Normalize header check
    sheet_headers = [h.strip().lower() for h in sheet.row_values(1)]
    expected_normalized = [h.strip().lower() for h in expected_headers]

    if sheet_headers != expected_normalized:
        print("⚠️ Sheet2 headers outdated or missing. Replacing...")
        sheet.delete_rows(1)
        sheet.insert_row(expected_headers, index=1)

    new_rows = []

    for entry in data:
        lead_id, client_id, timestamp, form_data = parse_submission(entry)

        if not lead_id or lead_id in existing_ids:
            continue

        row = [lead_id, client_id, timestamp] + [
            form_data.get("email", "N/A"),
            form_data.get("phone", "N/A")
        ]
        new_rows.append(row)
        existing_ids.add(lead_id)

    if new_rows:
        try:
            sheet.append_rows(new_rows, value_input_option="RAW")
            print(f"✅ Added {len(new_rows)} rows to Sheet2.")
        except Exception as e:
            print(f"❌ Error appending to Sheet2: {e}")
    else:
        print("✅ No new data to write.")

# Run it
update_google_sheet()